summaryrefslogtreecommitdiffstats
path: root/config-db/OpenSLX/DBSchema.pm
diff options
context:
space:
mode:
authorOliver Tappe2008-03-14 23:49:57 +0100
committerOliver Tappe2008-03-14 23:49:57 +0100
commit431e6e2f2811dc277feaca90f52466d623a74b0b (patch)
tree07b07b4d6970e49762f1eb76935c820d60552da1 /config-db/OpenSLX/DBSchema.pm
parent* Adding temporary plugin which install vmplayer in stage1 (diff)
downloadcore-431e6e2f2811dc277feaca90f52466d623a74b0b.tar.gz
core-431e6e2f2811dc277feaca90f52466d623a74b0b.tar.xz
core-431e6e2f2811dc277feaca90f52466d623a74b0b.zip
* added support for stage1 attributes that are stored along each plugin installed
into a vendor-OS. * an update of the slxos-plugin documentation is still missing (coming soon ;-) git-svn-id: http://svn.openslx.org/svn/openslx/openslx/trunk@1633 95ad53e4-c205-0410-b2fa-d234c58c8868
Diffstat (limited to 'config-db/OpenSLX/DBSchema.pm')
-rw-r--r--config-db/OpenSLX/DBSchema.pm31
1 files changed, 28 insertions, 3 deletions
diff --git a/config-db/OpenSLX/DBSchema.pm b/config-db/OpenSLX/DBSchema.pm
index 63774dfb..2be6dc7c 100644
--- a/config-db/OpenSLX/DBSchema.pm
+++ b/config-db/OpenSLX/DBSchema.pm
@@ -35,7 +35,7 @@ use OpenSLX::Basics;
### fk => foreign key (integer)
################################################################################
-my $VERSION = 0.28;
+my $VERSION = 0.29;
my $DbSchema = {
'version' => $VERSION,
@@ -162,6 +162,15 @@ my $DbSchema = {
# corresponding stage1, too.
],
},
+ 'installed_plugin_attr' => {
+ # (stage1-)attributes of installed plugins
+ 'cols' => [
+ 'id:pk', # primary key
+ 'installed_plugin_id:fk', # foreign key to installed plugin
+ 'name:s.128', # attribute name
+ 'value:s.255', # attribute value
+ ],
+ },
'meta' => {
# information about the database as such
'cols' => [
@@ -567,7 +576,7 @@ sub _schemaUpgradeDBFrom
0.21 => sub {
my $metaDB = shift;
# add new table installed_plugins
$metaDB->schemaAddTable(
'installed_plugin',
[
@@ -590,7 +599,7 @@ sub _schemaUpgradeDBFrom
0.23 => sub {
my $metaDB = shift;
- # add new column system.descripion
+ # add new column system.description
$metaDB->schemaAddColumns(
'system',
[
@@ -695,6 +704,22 @@ sub _schemaUpgradeDBFrom
return 1;
},
+ 0.29 => sub {
+ my $metaDB = shift;
+
+ # add new table installed_plugin_attrs
+ $metaDB->schemaAddTable(
+ 'installed_plugin_attr',
+ [
+ 'id:pk',
+ 'installed_plugin_id:fk',
+ 'name:s.128',
+ 'value:s.255',
+ ],
+ );
+
+ return 1;
+ },
);
1;
@@ -567,7 +576,7 @@ sub _schemaUpgradeDBFrom
0.21 => sub {
my $metaDB = shift;
- # add new table installed_plugins
+ # add new table installed_plugin
$metaDB->schemaAddTable(
'installed_plugin',